<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=gl
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Voltar á interface gráfica completa',
	'access_mode_texte' => 'Mostrar a interface de textos simplificada',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Modificar este artigo',
	'admin_modifier_auteur' => 'Modificar este autor',
	'admin_modifier_breve' => 'Modificar esta breve',
	'admin_modifier_mot' => 'Modificar esta palabra-clave',
	'admin_modifier_rubrique' => 'Modificar este tema',
	'admin_recalculer' => 'Recargar a páxina',
	'afficher_calendrier' => 'Presentar o calendario',
	'afficher_trad' => 'mostrar as traducións',
	'alerte_maj_impossible' => '<b>Aviso !</b> A actualización da base SQL sobre a versión @version@ é imposible, podería ser por causa dun problema de permisos de modificación da base de datos. Contacte co seu aloxador.',
	'alerte_modif_info_concourante' => 'AVISO : esta información foi modificada por outros. O valor actual é :',
	'analyse_xml' => 'Análise XML',
	'annuler' => 'Anular',
	'antispam_champ_vide' => 'Deixe este campo baleiro, por favor :',
	'articles_recents' => 'Artigos máis recentes',
	'avis_archive_incorrect' => 'o ficheiro arquivado non é un ficheiro SPIP',
	'avis_archive_invalide' => 'o ficheiro arquivado non é válido',
	'avis_attention' => 'ATENCIÓN!',
	'avis_champ_incorrect_type_objet' => 'Nome de campo incorrecto @name@ para o obxecto de tipo @type@',
	'avis_colonne_inexistante' => 'A columna @col@ non existe',
	'avis_erreur' => 'Erro: ver abaixo',
	'avis_erreur_connexion' => 'Erro de conexión',
	'avis_erreur_cookie' => 'problema de cookie',
	'avis_erreur_fonction_contexte' => 'Erro de programación. Esta función non debe ser chamada neste contexto.',
	'avis_erreur_mysql' => 'Erro SQL',
	'avis_erreur_sauvegarde' => 'Erro gardando (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Problema co acceso ao espazo privado',

	// B
	'barre_a_accent_grave' => 'Inserir un A con acento grave maiúsculo',
	'barre_aide' => 'Utilice os recursos tipográficos para enriquecer a súa publicación',
	'barre_e_accent_aigu' => 'Inserir un E con acento agudo maiúsculo',
	'barre_eo' => 'Inserir un E dentro do O',
	'barre_eo_maj' => 'Inserir un E dentro do O maiúsculo',
	'barre_euro' => 'Inserir o símbolo €',
	'barre_gras' => 'Poñer en {{gras}}',
	'barre_guillemets' => 'Encerrar entre « ángulos »',
	'barre_guillemets_simples' => 'Encerrar entre “comas dobres”',
	'barre_intertitre' => 'Transformar en {{{intertítulo}}}',
	'barre_italic' => 'Poñer en {cursiva}',
	'barre_lien' => 'Transformar en [ligazón de hipertexto->http://...]',
	'barre_lien_input' => 'Indicar o enderezo de seu web (pode indicar un enderezo de web coa forma http://www.monsite/com ou simplemente indicar o número dun artigo deste web.',
	'barre_note' => 'Transformar en [[Nota a rodapé]]',
	'barre_paragraphe' => 'Crear un parágrafo',
	'barre_quote' => '<quote>Citar unha mensaxe</quote>',
	'bouton_changer' => 'Trocar',
	'bouton_chercher' => 'Buscar',
	'bouton_choisir' => 'Elexir',
	'bouton_deplacer' => 'Desprazar',
	'bouton_download' => 'Descargar',
	'bouton_enregistrer' => 'Rexistrar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desactivar a mensaxería interna',
	'bouton_radio_envoi_annonces' => 'Enviar os anuncios editoriais',
	'bouton_radio_non_envoi_annonces' => 'Non enviar novas',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Non enviar a lista de novidades',
	'bouton_recharger_page' => 'recargar a páxina',
	'bouton_telecharger' => 'Cargar',
	'bouton_upload' => 'Cargar',
	'bouton_valider' => 'Validar',

	// C
	'cal_apresmidi' => 'mediodía',
	'cal_jour_entier' => 'día enteiro',
	'cal_matin' => 'mañá',
	'cal_par_jour' => 'calendario por día',
	'cal_par_mois' => 'calendario por mes',
	'cal_par_semaine' => 'calendario por semana',
	'choix_couleur_interface' => 'cor',
	'choix_interface' => 'escolla de interface',
	'colonne' => 'Columna',
	'confirm_changer_statut' => 'Coidado, pediu cambiar o estado deste elemento. Quere proceder?',
	'correcte' => 'correcto',

	// D
	'date_aujourdhui' => 'hoxe',
	'date_avant_jc' => 'a. de J.C.',
	'date_dans' => 'en @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'mañá;',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ ás @heure@',
	'date_fmt_jour_mois' => '@jour@ de @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ do @annee@',
	'date_fmt_mois_annee' => '@nommois@ do @annee@',
	'date_fmt_nomjour_date' => 'o @nomjour@ @date@',
	'date_heures' => 'horas',
	'date_hier' => 'onte',
	'date_il_y_a' => 'fai @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'domingo',
	'date_jour_1_abbr' => 'dom.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'luns',
	'date_jour_2_abbr' => 'lun.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'martes',
	'date_jour_3_abbr' => 'mar.',
	'date_jour_3_initiale' => 'm.',
	'date_jour_4' => 'mércores',
	'date_jour_4_abbr' => 'mer.',
	'date_jour_4_initiale' => 'm.',
	'date_jour_5' => 'xoves',
	'date_jour_5_abbr' => 'xov.',
	'date_jour_5_initiale' => 'x.',
	'date_jour_6' => 'venres',
	'date_jour_6_abbr' => 'ven.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'sábado',
	'date_jour_7_abbr' => 'sáb.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'días',
	'date_minutes' => 'minutos',
	'date_mois' => 'meses',
	'date_mois_1' => 'xaneiro',
	'date_mois_10' => 'outubro',
	'date_mois_10_abbr' => 'out.',
	'date_mois_11' => 'novembro',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'decembro',
	'date_mois_12_abbr' => 'dec.',
	'date_mois_1_abbr' => 'xan.',
	'date_mois_2' => 'febreiro',
	'date_mois_2_abbr' => 'feb.',
	'date_mois_3' => 'marzo',
	'date_mois_3_abbr' => 'marz.',
	'date_mois_4' => 'abril',
	'date_mois_4_abbr' => 'abr.',
	'date_mois_5' => 'maio',
	'date_mois_5_abbr' => 'mai',
	'date_mois_6' => 'xuño',
	'date_mois_6_abbr' => 'xuño',
	'date_mois_7' => 'xullo',
	'date_mois_7_abbr' => 'xullo',
	'date_mois_8' => 'agosto',
	'date_mois_8_abbr' => 'ago.',
	'date_mois_9' => 'setembro',
	'date_mois_9_abbr' => 'set.',
	'date_saison_1' => 'inverno',
	'date_saison_2' => 'primavera',
	'date_saison_3' => 'verán',
	'date_saison_4' => 'outono',
	'date_secondes' => 'segundos',
	'date_semaines' => 'semanas',
	'date_un_mois' => 'mes',
	'date_une_heure' => 'hora',
	'date_une_minute' => 'minuto',
	'date_une_seconde' => 'segundo',
	'date_une_semaine' => 'semana',
	'dirs_commencer' => ' para comezar realmente a instalación',
	'dirs_preliminaire' => 'Preliminar: <b>Regular os permisos de acceso</b>',
	'dirs_probleme_droits' => 'Problema de permisos de acceso',
	'dirs_repertoires_absents' => '<p><b>Os directorios seguintes non foron atopados :</b></p><ul>@bad_dirs@.</ul>
  <p>É probable que iso se deba a un problema de uso de maiúsculas ou minúsculas.
  Verifique que as minúsculas e maiúsculas destes cartafoles concorden ben co que se amosa
 aquí abaixo; se non é ese o caso, renomee os cartafoles co seu programa de FTP de xeito que se corrixa o erro.</p>
  <p>Logo de facer este cambio, poderá ',
	'dirs_repertoires_suivants' => '<p><b>Os cartafoles seguintes impiden o acceso con dereitos para escritura :</b></p><ul>@bad_dirs@.</ul>
  <p>Para arranxalo, empregue o seu cliente de FTP e cambie os permisos de acceso de cada un
  deles. O procedemento está explicado polo miúdo na guía de instalación.</p>
  <p>Unha vez feito isto, poderá ',
	'double_occurrence' => 'Dobre ocorrencia de @balise@',

	// E
	'en_cours' => 'en curso',
	'envoi_via_le_site' => 'Envío vía o sitio web',
	'erreur' => 'Erro',
	'erreur_balise_non_fermee' => 'a última baliza non foi pechada :',
	'erreur_texte' => 'erro(s)',
	'etape' => 'Etapa',

	// F
	'fichier_introuvable' => 'O ficheiro @fichier@ non foi atopado', # MODIF
	'form_auteur_confirmation' => 'Confirme o seu enderezo de correo',
	'form_auteur_email_modifie' => 'Modificouse o seu enderezo de correo.',
	'form_auteur_envoi_mail_confirmation' => 'Un correo electrónico de confirmación acaba de ser enviado a @email@. Debería visitar ese enderezo web mencionado no correo para validar o seu enderezo de correo.',
	'form_auteur_mail_confirmation' => 'Ola,

Vostede solicitou cambiar o seu enderezo de correo.
Para confirmar o seu novo enderezo, cómpre que se conecta co
enderezo seguinte (caso contrario, a súa solicitude
sera ignorada) :

    @url@
',
	'form_deja_inscrit' => 'Xa está inscrito.',
	'form_email_non_valide' => 'O seu enderezo de correo-e. non é válido.',
	'form_forum_access_refuse' => 'Non tes acceso a este web.',
	'form_forum_bonjour' => 'Ola, @nom@,',
	'form_forum_email_deja_enregistre' => 'Este enderezo de correo xa está rexistrado, daquela pode empregar a súa chave de sempre.',
	'form_forum_identifiant_mail' => 'Enviouselle a vostede o seu novo identificador por correo electrónico.',
	'form_forum_identifiants' => 'Identificadores persoais',
	'form_forum_indiquer_nom_email' => 'Indique aquí o seu nome e o seu enderezo de correo. Axiña recibirá o seu identificador persoal por correo electrónico.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(esta é unha mensaxe automática)',
	'form_forum_pass' => 'chave:',
	'form_forum_probleme_mail' => 'Problema co correo: non se lle puido enviar o identificador.',
	'form_forum_voici1' => 'Velaquí os seus datos identificadores para participar na vida
do web "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Estes son os datos que precisa para propor artigos en "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Indique o seu enderezo de correo-e.',
	'form_indiquer_nom' => 'Indica o teu nome.',
	'form_indiquer_nom_site' => 'Indique o nome do seu web.',
	'form_pet_deja_enregistre' => 'Este web xa foi rexistrado',
	'form_pet_signature_pasprise' => 'A túa sinatura non foi tida en conta.',
	'form_prop_confirmer_envoi' => 'Confirmar o envío',
	'form_prop_description' => 'Descrición/comentario',
	'form_prop_enregistre' => 'A súa proposta foi rexistrada, estará en liña en canto sexa
  validada polo equipo de xestión deste web.', # MODIF
	'form_prop_envoyer' => 'Enviar unha mensaxe',
	'form_prop_indiquer_email' => 'Indique un enderezo de correo-e. correcto',
	'form_prop_indiquer_nom_site' => 'Indique o nome do web.',
	'form_prop_indiquer_sujet' => 'Escrebe o asunto da mensaxe',
	'form_prop_message_envoye' => 'Mensaxe enviada',
	'form_prop_non_enregistre' => 'A súa proposta non foi rexistrada.',
	'form_prop_sujet' => 'Asunto',
	'form_prop_url_site' => 'Enderezo (URL) do web', # MODIF
	'forum_non_inscrit' => 'Aínda non se rexistrou, ou o enderezo ou a chave son incorrectos.',
	'forum_par_auteur' => 'por @auteur@',
	'forum_titre_erreur' => 'Erro...',

	// I
	'ical_texte_rss_articles' => 'O ficheiro «backend» dos artigos deste web encóntrase no enderezo:',
	'ical_texte_rss_articles2' => 'Pode tamén obter os ficheiros «backend» para os artigos de cada sección do web:',
	'ical_texte_rss_breves' => 'Está dispoñible un ficheiro que contén as breves do web. Especificando un número de sección obterá unicamente as breves de tal sección.',
	'icone_a_suivre' => 'Panel de control',
	'icone_admin_site' => 'Xestión do web',
	'icone_agenda' => 'Axenda',
	'icone_aide_ligne' => 'Axuda en liña',
	'icone_articles' => 'Artigos',
	'icone_auteurs' => 'Equipo de redacción',
	'icone_brouteur' => 'Navegación rápida',
	'icone_configuration_site' => 'Configuración',
	'icone_configurer_site' => 'Configurar o teu web',
	'icone_creer_nouvel_auteur' => 'Crear un novo autor/a',
	'icone_creer_rubrique' => 'Crear unha sección',
	'icone_creer_sous_rubrique' => 'Crear unha subsección',
	'icone_deconnecter' => 'Desconectarse',
	'icone_discussions' => 'Discusións',
	'icone_doc_rubrique' => 'Documento dos temas',
	'icone_ecrire_article' => 'Escribir un novo artigo',
	'icone_edition_site' => 'Edición',
	'icone_gestion_langues' => 'Xestión das linguas',
	'icone_informations_personnelles' => 'Información persoal',
	'icone_interface_complet' => 'Interface completa',
	'icone_interface_simple' => 'Interface sinxela',
	'icone_maintenance_site' => 'Mantemento do web',
	'icone_messagerie_personnelle' => 'Mensaxería persoal',
	'icone_repartition_debut' => 'Mostrar distribución dende o principio',
	'icone_rubriques' => 'Temas',
	'icone_sauver_site' => 'Copia de seguridade do web',
	'icone_site_entier' => 'Todo o web',
	'icone_sites_references' => 'Webs referidos',
	'icone_statistiques' => 'Estatísticas do web',
	'icone_suivi_activite' => 'Seguir a vida do web',
	'icone_suivi_actualite' => 'Evolución do web',
	'icone_suivi_pettions' => 'Seguir/xestionar as solicitudes',
	'icone_suivi_revisions' => 'Modificacións dos artigos',
	'icone_supprimer_document' => 'Borrar este documento',
	'icone_supprimer_image' => 'Borrar esta imaxe',
	'icone_tous_articles' => 'Os teus artigos',
	'icone_tous_auteur' => 'Todo o equipo de redacción',
	'icone_tous_visiteur' => 'Todos os visitantes',
	'icone_visiter_site' => 'Ver o web público',
	'icone_voir_en_ligne' => 'Ver en liña',
	'img_indisponible' => 'imaxe non dispoñíbel',
	'impossible' => 'imposíbel',
	'info_a_suivre' => 'PANEL DE CONTROL »',
	'info_acces_interdit' => 'Acceso prohibido',
	'info_acces_refuse' => 'Acceso rexeitado',
	'info_action' => 'Acción: @action@',
	'info_administrer_rubriques' => 'Podes administrar este tema e os seus apartados',
	'info_adresse_non_indiquee' => 'Non indicou un enderezo de proba!',
	'info_aide' => 'AXUDA:',
	'info_ajouter_mot' => 'Engadir esta palabra',
	'info_annonce' => 'ANUNCIO',
	'info_annonces_generales' => 'Anuncios xerais :',
	'info_article_propose' => 'Artigo proposto',
	'info_article_publie' => 'Artigo publicado',
	'info_article_redaction' => 'Artigo en proceso de redacción',
	'info_article_refuse' => 'Artigo rexeitado',
	'info_article_supprime' => 'Artigo eliminado',
	'info_articles' => 'Artigos',
	'info_articles_a_valider' => 'Os artigos por validar',
	'info_articles_nb' => '@nb@ artigos',
	'info_articles_proposes' => 'Artigos propostos',
	'info_articles_un' => '1 artigo',
	'info_auteurs_nombre' => 'autor(as/es):',
	'info_authentification_ftp' => 'Autentificación (por FTP).',
	'info_breves_2' => 'breves',
	'info_breves_nb' => '@nb@ breves',
	'info_breves_un' => '1 breve',
	'info_connexion_refusee' => 'Conexión rexeitada',
	'info_contact_developpeur' => 'Tes que contactar cun desenrolador.', # MODIF
	'info_contenance' => 'Este web contén:',
	'info_contribution' => 'contribucións no foro', # MODIF
	'info_copyright' => '@spip@ é un programa libre distribuído @lien_gpl@.',
	'info_copyright_doc' => 'Para máis información, vaia a <a href="@spipnet@">http://www.spip.net/gl</a>.', # MODIF
	'info_copyright_gpl' => 'con licenza GPL',
	'info_cours_edition' => 'Os artigos en proceso de edición', # MODIF
	'info_creer_repertoire' => 'Debe crear un ficheiro ou cartafol chamado :',
	'info_creer_repertoire_2' => 'dentro do subcartafol <b>@repertoire@</b>, e logo:',
	'info_creer_vignette' => 'creación automática da viñeta',
	'info_deplier' => 'Despregar',
	'info_descriptif_nombre' => 'descrición(s):',
	'info_description' => 'Descrición:',
	'info_description_2' => 'Descrición:',
	'info_dimension' => 'Dimensións:',
	'info_documents_nb' => '@nb@ documentos',
	'info_documents_un' => '1 documento',
	'info_ecire_message_prive' => 'Escribir unha mensaxe privada',
	'info_email_invalide' => 'Enderezo de correo-e. incorrecto.',
	'info_en_cours_validation' => 'Os seus artigos en proceso de redacción',
	'info_en_ligne' => 'Agora en liña :',
	'info_envoyer_message_prive' => 'enviar unha mensaxe privada a esta persoa',
	'info_erreur_requete' => 'Erro na petición:',
	'info_erreur_squelette2' => 'Ningún esqueleto <b>@fichier@</b> está dispoñible...',
	'info_erreur_systeme' => 'Erro do sistema (errno @errsys@)',
	'info_erreur_systeme2' => 'O disco duro pode ser que estea cheo, ou a base de datos danada.<br />
<span style="color:red;">Probe a <a href=\'@script@\'>reparar a base</a>, ou contacte co seu aloxador.</span>',
	'info_fini' => 'Rematou!',
	'info_format_image' => 'Formatos de imaxes que poden ser utilizados para crear as viñetas: @gd_formats@.',
	'info_format_non_defini' => 'formato non definido',
	'info_grand_ecran' => 'Pantalla grande',
	'info_image_aide' => 'AXUDA',
	'info_image_process_titre' => 'Método de produción das viñetas',
	'info_impossible_lire_page' => '<b>Erro!</b> Foi imposible ler a páxina <tt><html>@test_proxy@</html></tt> a través do proxy <tt>',
	'info_installation_systeme_publication' => 'Instalación do sistema de publicación...',
	'info_installer_documents' => 'Pode instalar automaticamente todos os documentos contidos no cartafol ou directorio @upload@.',
	'info_installer_ftp' => 'Como administrador, pode instalar (por FTP) os ficheiros no cartafol  /@upload@ para despois podelos seleccionar directamente aquí.', # MODIF
	'info_installer_images' => 'Podes instalar imaxes nos formatos PNG, JPEG e GIF.',
	'info_installer_images_dossier' => 'Instalar imaxes no cartafol @upload@ para poder seleccionalas aquí.',
	'info_interface_complete' => 'Interface completa',
	'info_interface_simple' => 'Interface sinxela',
	'info_joindre_document_article' => 'Podes engadir a este artigo documentos do tipo',
	'info_joindre_document_rubrique' => 'Podes engadir neste tema documentos do tipo',
	'info_joindre_documents_article' => 'Podes engadir ó teu artigo documentos do tipo:',
	'info_l_article' => 'o artigo',
	'info_la_breve' => 'a breve',
	'info_la_rubrique' => 'o tema',
	'info_langue_principale' => 'Idioma principal do web',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'por @les_auteurs@',
	'info_logo_format_interdit' => 'Só están permitidos os logos nos seguintes formatos @formats@.',
	'info_logo_max_poids' => 'Os logos deben obrigatoriamente ter menos de @maxi@ (este ficheiro ten @actuel@).',
	'info_mail_fournisseur' => 'oteu@aloxador.com',
	'info_message_2' => 'MENSAXE',
	'info_message_supprime' => 'MENSAXE ELIMINADA',
	'info_messages_nb' => '@nb@ mensaxes',
	'info_messages_un' => '1 mensaxe',
	'info_mise_en_ligne' => 'Data de posta en liña:',
	'info_modification_parametres_securite' => 'modificacións dos parámetros de seguridade',
	'info_mois_courant' => 'Neste mes:',
	'info_mot_cle_ajoute' => 'A seguinte palabra-clave foi engadida a',
	'info_multi_herit' => 'Lingua predeterminada',
	'info_multi_langues_soulignees' => 'As <u>linguas subliñadas</u> benefícianse dunha tradución de todos os textos da interface. Se vostede selecciona estas linguas, haberá numerosos elementos do web público (datos, formularios)que serán automaticamente traducidos. Para as linguas non subliñadas, estes elementos aparecerán na lingua principal do web.', # MODIF
	'info_multilinguisme' => 'Multilingüismo',
	'info_nom_non_utilisateurs_connectes' => 'O seu nome non aparece na lista de persoas conectadas.', # MODIF
	'info_nom_utilisateurs_connectes' => 'O seu nome aparece na lista de persoas conectadas.', # MODIF
	'info_nombre_en_ligne' => 'Actualmente en liña:',
	'info_non_resultat' => 'Non hai ningún resultado con "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Non está empregando a mensaxería interna deste web.',
	'info_nouveau_message' => 'TES UNHA NOVA MENSAXE',
	'info_nouveaux_messages' => 'TES @total_messages@ NOVAS MENSAXES',
	'info_numero_abbreviation' => 'Núm. ',
	'info_obligatoire' => 'Esta información é obrigada',
	'info_pense_bete' => 'NOTA',
	'info_petit_ecran' => 'Pantalla pequena',
	'info_petition_close' => 'Solicitude pechada',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'Foron atopadas varias palabras-clave para "@cherche_mot@":',
	'info_portfolio_automatique' => 'Portafolio automático:',
	'info_premier_resultat' => '[@debut_limit@ primeiros resultados de @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primeiros resultados de @total@]',
	'info_propose_1' => '[@nom_site_spip@] Proposto: @titre@',
	'info_propose_2' => 'Artigo proposto
---------------',
	'info_propose_3' => 'O artigo "@titre@" foi proposto para a súa publicación.',
	'info_propose_4' => 'Consúlteo e achegue a súa opinión',
	'info_propose_5' => 'no foro correspondente. Está dispoñible no enderezo : ',
	'info_publie_01' => 'O artigo "@titre@" foi validado por @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICADO: @titre@',
	'info_publie_2' => 'Artigo publicado
--------------',
	'info_rechercher' => 'Buscar',
	'info_rechercher_02' => 'Buscar:',
	'info_remplacer_vignette' => 'Trocar a viñeta por defecto por un logo persoal:',
	'info_rubriques_nb' => '@nb@ seccións',
	'info_rubriques_un' => '1 seccións',
	'info_sans_titre_2' => 'sen título',
	'info_selectionner_fichier' => 'Pode seleccionar un ficheiro do cartafol @upload@',
	'info_selectionner_fichier_2' => 'Seleccionar un ficheiro:',
	'info_sites_nb' => '@nb@ webs',
	'info_sites_un' => '1 web',
	'info_supprimer_vignette' => 'suprimir a viñeta',
	'info_symbole_bleu' => 'O símbolo <b>azul</b> indica unha <b>nota</b>: ou sexa, unha mensaxe para o seu uso persoal.',
	'info_symbole_jaune' => 'O símbolo <b>amarelo</b> indica un <b>anuncio para todo o equipo de redacción</b> : modificable polo equipo de xestión, e visible por toda a redacción.', # MODIF
	'info_symbole_vert' => 'O símbolo <b>verde</b> indica as <b>mensaxes intercambiadas con outros usuarios</b> do web.', # MODIF
	'info_telecharger_nouveau_logo' => 'Cargar un novo logo:',
	'info_telecharger_ordinateur' => 'Cargar dende a súa computadora:',
	'info_tous_resultats_enregistres' => '[todos os resultados foron rexistrados]',
	'info_tout_afficher' => 'Amosar todo',
	'info_travaux_texte' => 'Este web non está aínda configurado. Volva máis adiante...',
	'info_travaux_titre' => 'Web en construción',
	'info_trop_resultat' => 'Resultados de máis para "@cherche_mot@" ; por favor, afine a súa procura.',
	'info_utilisation_messagerie_interne' => 'Estás empregando a mensaxería interna deste web.',
	'info_valider_lien' => 'validar esta ligazón',
	'info_verifier_image' => ', verifique que as imaxes foron transferidas correctamente.',
	'info_vignette_defaut' => 'Viñeta predeterminada',
	'info_vignette_personnalisee' => 'Viñeta personalizada',
	'info_visite' => 'visita:',
	'info_vos_rendez_vous' => 'As túas citas pendentes',
	'infos_vos_pense_bete' => 'As súas notas',

	// L
	'lien_afficher_icones_seuls' => 'Amosar só as iconas',
	'lien_afficher_texte_icones' => 'Amosar as iconas e o texto',
	'lien_afficher_texte_seul' => 'Amosar só o texto',
	'lien_liberer' => 'liberar',
	'lien_liberer_tous' => 'Liberalos todos',
	'lien_nouvea_pense_bete' => 'NOVA NOTA',
	'lien_nouveau_message' => 'NOVA MENSAXE',
	'lien_nouvelle_annonce' => 'NOVO ANUNCIO',
	'lien_petitions' => 'SOLICITUDE',
	'lien_popularite' => 'popularidade : @popularite@%',
	'lien_racine_site' => 'RAÍZ DO WEB',
	'lien_reessayer' => 'reintentar',
	'lien_repondre_message' => 'Responder a esta mensaxe',
	'lien_supprimer' => 'Suprimir',
	'lien_tout_afficher' => 'Amosar todo',
	'lien_visite_site' => 'visitar este web',
	'lien_visites' => '@visites@ visitas',
	'lien_voir_auteur' => 'Ver est@ autor/a',
	'ligne' => 'Liña',
	'login' => 'Conexión',
	'login_acces_prive' => 'acceso ao espazo privado',
	'login_autre_identifiant' => 'conectarse con outro identificador',
	'login_cookie_accepte' => 'Axuste o seu navegador para que as acepte (cando menos para este web).',
	'login_cookie_oblige' => 'Para indentificarse dun xeito seguro neste webr, ten que aceptar as cookies.',
	'login_deconnexion_ok' => 'Desconexión realizada.',
	'login_erreur_pass' => 'Erro na chave.',
	'login_espace_prive' => 'Espazo privado',
	'login_identifiant_inconnu' => 'O identificador « @login@ » é descoñecido.',
	'login_login' => 'Login:',
	'login_login2' => 'Login (identificador de conexión ao web):', # MODIF
	'login_login_pass_incorrect' => '(Login ou chave incorrectos.)',
	'login_motpasseoublie' => 'esqueceu a chave?',
	'login_non_securise' => 'Atención, este formulario non é seguro.
  Se non quere que a súa chave poida ser interceptada
  na rede, active o Javascript no seu navegador e',
	'login_nouvelle_tentative' => 'Nova tentativa',
	'login_par_ici' => 'Vostede está xa rexistrado... por aquí...',
	'login_pass2' => 'Chave :',
	'login_preferez_refuser' => '<b>Se prefire non usar as cookies</b>, ten outro método de conexión (menos seguro) á súa disposición:',
	'login_recharger' => 'recargar a páxina',
	'login_rester_identifie' => 'Permanecer identificado algúns días', # MODIF
	'login_retour_public' => 'Volver ao web público',
	'login_retour_site' => 'Volver ao web público',
	'login_retoursitepublic' => 'volver ao web público',
	'login_securise' => 'Inicio de sesión securizado',
	'login_sinscrire' => 'Inscribirse', # MODIF
	'login_test_navigateur' => 'proba navegador/reconexión',
	'login_verifiez_navigateur' => '(De todos os xeitos, comprobe que o seu navegador non memorizou a súa chave...)',

	// M
	'masquer_colonne' => 'Ocultar esta columna',
	'masquer_trad' => 'ocultar as traducións',
	'module_fichiers_langues' => 'Ficheiros de lingua',

	// N
	'navigateur_pas_redirige' => 'Se o seu navegador non é redirixido, prema aquí para continuar.',
	'numero' => 'Número',

	// O
	'occurence' => 'Ocorrencia',
	'onglet_affacer_base' => 'Eliminar a base',
	'onglet_auteur' => 'A persoa',
	'onglet_contenu_site' => 'Contido do web',
	'onglet_evolution_visite_mod' => 'Evolución',
	'onglet_fonctions_avances' => 'Funcións avanzadas',
	'onglet_informations_personnelles' => 'Informacións persoais',
	'onglet_interactivite' => 'Interactividade',
	'onglet_messagerie' => 'Mensaxería',
	'onglet_repartition_rubrique' => 'Distribución por seccións',
	'onglet_save_restaur_base' => 'Gardar/restaurar a base',
	'onglet_vider_cache' => 'Baleirar a memoria caché',

	// P
	'pass_choix_pass' => 'Elixa súa nova chave:',
	'pass_erreur' => 'Erro',
	'pass_erreur_acces_refuse' => '<b>Erro:</b> xa non ten acceso a este web.',
	'pass_erreur_code_inconnu' => '<b>Erro:</b> este código non se corresponde con ninguén con acceso a este web.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Erro:</b> o enderezo <tt>@email_oubli@</tt> non foi rexistrado neste web.',
	'pass_erreur_non_valide' => '<b>Erro:</b> o correo-e. <tt>@email_oubli@</tt> non é válido!',
	'pass_erreur_probleme_technique' => '<b>Erro:</b> debido a un problema técnico, a mensaxe de correo non puido ser enviada.',
	'pass_espace_prive_bla' => 'O espazo privado deste web está aberto ás
  visitas, logo de se rexistrar. Unha vez que se rexistre,
  poderá consultar os artigos en proceso de redacción,
  propor novos artigos e participar en todos os foros.', # MODIF
	'pass_forum_bla' => 'Solicitou participar nun foro reservado para os visitantes rexistrados.', # MODIF
	'pass_indiquez_cidessous' => 'Indique aquí embaixo o enderezo do correo co que se
  rexistrara no seu momento. Recibirá un correo indicándolle os pasos a seguir para
  recuperar o seu acceso.',
	'pass_mail_passcookie' => '(esta é unha mensaxe automática)
Para recuperar o seu acceso a
@nom_site_spip@ (@adresse_site@)

Diríxase ao seguinte enderezo:


     @sendcookie@

Daquela, poderá elixir unha nova chave
e reconectar co web.

', # MODIF
	'pass_mot_oublie' => 'Chave esquecida',
	'pass_nouveau_enregistre' => 'A súa nova chave foi rexistrada.',
	'pass_nouveau_pass' => 'Nova chave',
	'pass_ok' => 'ben',
	'pass_oubli_mot' => 'Chave esquecida',
	'pass_quitter_fenetre' => 'Pechar esta xanela',
	'pass_rappel_login' => 'Lembra: o teu identificador (login) é « @login@ «.',
	'pass_recevoir_mail' => 'Recibirás un correo indicándote os pasos a seguir para recuperar o teu acceso.', # MODIF
	'pass_retour_public' => 'Volver ao web público',
	'pass_rien_a_faire_ici' => 'Non hai nada que facer aquí.',
	'pass_vousinscrire' => 'Inscríbase neste web',
	'precedent' => 'anterior',
	'previsualisation' => 'Previsualización',
	'previsualiser' => 'Previsualizar',

	// R
	'retour' => 'Volver',

	// S
	'spip_conforme_dtd' => 'SPIP considera este documento conforme co seu DOCTYPE :',
	'squelette' => 'esqueleto',
	'squelette_inclus_ligne' => 'esqueleto incluído, liña',
	'squelette_ligne' => 'esquelto, liña',
	'stats_visites_et_popularite' => '@visites@ visitas; popularidade: @popularite@',
	'suivant' => 'seguinte',

	// T
	'taille_ko' => '@taille@ KB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ bytes',
	'taille_octets_bi' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Cando xa estea familiarizado/a coa interface, poderá premer sobre «',
	'texte_actualite_site_2' => 'interface completa',
	'texte_actualite_site_3' => '» para obter máis posibilidades.',
	'texte_creation_automatique_vignette' => 'A creación automática de viñetas de previsualización está activada. Se emprega este formulario para subir ao servidor imaxes no(s) formato(s) @gd_formats@, irán acompañadas dunha viñeta cun tamaño máximo de @taille_preview@ píxels.',
	'texte_documents_associes' => 'Os seguintes documentos están vencellados ao artigo,
  mais non foron inseridos directamente. Dependendo do formato da páxina no web público,
  poderán aparecer en forma de documentos anexos.',
	'texte_erreur_mise_niveau_base' => 'Hai un erro na base de datos tras a actualización.
  A imaxe <b>@fichier@</b> non foi engadida ao (artigo @id_article@).
  Tome nota deste aviso, reintente a actualización, 
  e finalmente verifique que as imaxes aparecen sempre
  nos artigos.',
	'texte_erreur_visiteur' => 'Vostede tentou de acceder ao espazo privado cun identificador que non llo permite',
	'texte_inc_auth_1' => 'Identificouse co
  identificador <b>@auth_login@</b>, mais este non existe na base de datos.
  Probe',
	'texte_inc_auth_2' => 'reconectar',
	'texte_inc_auth_3' => ', despois de reiniciar o seu navegador.',
	'texte_inc_config' => 'As modificacións que faga nestas páxinas influirán notábelmente no
  funcionamento do web. Recoméndaselle non as modificar namentres que non estea 
  un pouco ao tanto do funcionamento do sistema SPIP.
  <br /><br /><b>En xeral, é moi recomendábel que estas páxinas sexan
  xestionadas polo/a webmáster principal do web.</b>',
	'texte_inc_meta_1' => 'O sistema encontrou un erro tras a escritura do ficheiro <code>@fichier@</code>. Revíseo co perfil de administrador/a do web.', # MODIF
	'texte_inc_meta_2' => 'Comprobar os permisos de escritura',
	'texte_inc_meta_3' => 'no cartafol <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'en proceso de redacción',
	'texte_statut_poubelle' => 'no lixo',
	'texte_statut_propose_evaluation' => 'proposto para avaliación',
	'texte_statut_publie' => 'publicado en liña',
	'texte_statut_refuse' => 'rexeitado',
	'titre_ajouter_mot_cle' => 'ENGADIR UNHA PALABRA-CLAVE:',
	'titre_cadre_raccourcis' => 'ATALLOS:',
	'titre_changer_couleur_interface' => 'Trocar a cor da interface',
	'titre_image_admin_article' => 'Podes administrar este artigo',
	'titre_image_administrateur' => 'Xestión', # MODIF
	'titre_image_aide' => 'Axuda sobre este elemento',
	'titre_image_auteur_supprime' => 'Autor/a suprimido',
	'titre_image_redacteur' => 'Redactor/a sen acceso',
	'titre_image_redacteur_02' => 'Redactor/a',
	'titre_image_visiteur' => 'Visitante',
	'titre_joindre_document' => 'ANEXAR UN DOCUMENTO',
	'titre_mots_cles' => 'PALABRAS-CLAVE',
	'titre_probleme_technique' => 'Atención: un problema técnico (servidor SQL) impide o acceso a esta parte do web. Grazas pola súa comprensión.',
	'titre_publier_document' => 'PUBLICAR UN DOCUMENTO NESTE TEMA',
	'titre_signatures_attente' => 'Sinaturas en espera de validación',
	'titre_signatures_confirmees' => 'Sinaturas confirmadas',
	'titre_statistiques' => 'Estatísticas do web',
	'titre_titre_document' => 'Título do documento:',
	'todo' => 'próximos',
	'trad_reference' => '(referencia de traducions)',

	// Z
	'zbug_balise_b_aval' => ' : baliza B en aval',
	'zbug_balise_inexistante' => 'A baliza @balise@ está mal declarada para @from@',
	'zbug_balise_sans_argument' => 'Falta o argumento na baliza @balise@',
	'zbug_boucle' => 'bucle',
	'zbug_boucle_recursive_undef' => 'Bucle recursivo non definido: @nom@',
	'zbug_calcul' => 'cálculo',
	'zbug_champ_hors_boucle' => 'Campo @champ@ fóra de bucle',
	'zbug_champ_hors_motif' => 'Campo @champ@ fóra dun contexto @motif@',
	'zbug_code' => 'código',
	'zbug_critere_inconnu' => 'Criterio descoñecido @critere@',
	'zbug_distant_interdit' => 'Base externa prohibida',
	'zbug_doublon_table_sans_cle_primaire' => 'Doublons sobre unha táboa sen clave primaria atómica',
	'zbug_doublon_table_sans_index' => 'Doublons nunha táboa sen index',
	'zbug_erreur_boucle_double' => 'Dobre definición do boucle @id@',
	'zbug_erreur_boucle_fermant' => 'Falta o cerre do bucle @id@',
	'zbug_erreur_boucle_syntaxe' => 'Sintaxe de bucle incorrecta',
	'zbug_erreur_compilation' => 'Erro de compilación',
	'zbug_erreur_execution_page' => 'Erro de execución',
	'zbug_erreur_filtre' => 'Filtro @filtre@ non definido',
	'zbug_erreur_meme_parent' => 'O criterio {meme_parent} non é aplicábel máis que aos bucles (FORUMS) ou (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Erro(s) no esqueleto',
	'zbug_hors_compilation' => 'Deixar compilación',
	'zbug_info_erreur_squelette' => 'Erro no web',
	'zbug_inversion_ordre_inexistant' => 'Inversión dunha orde inexistente',
	'zbug_pagination_sans_critere' => 'A baliza #PAGINATION está sen criterio {pagination} ou está empregada nun bucle recursivo',
	'zbug_parametres_inclus_incorrects' => 'Parámetro de inclusión incorrecto: @param@',
	'zbug_profile' => 'Tempo de cálculo : @time@',
	'zbug_resultat' => 'resultado',
	'zbug_serveur_indefini' => 'Servidor SQL non definido',
	'zbug_statistiques' => 'Estatísticas de consultas SQL ordenadas por duración',
	'zbug_table_inconnue' => 'Táboa SQL « @table@ » descoñecida',
	'zxml_connus_attributs' => 'atributos coñecidos',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atributo descoñecido',
	'zxml_inconnu_balise' => 'baliza descoñecida',
	'zxml_inconnu_entite' => 'entidade descoñecida',
	'zxml_inconnu_id' => 'ID descoñecida',
	'zxml_mais_de' => 'mais de',
	'zxml_non_conforme' => 'non é conforme co motivo',
	'zxml_non_fils' => 'non é un fío de',
	'zxml_nonvide_balise' => 'a baliza non está baleira',
	'zxml_obligatoire_attribut' => 'atributo obrigatorio mais ausente en',
	'zxml_succession_fils_incorrecte' => 'sucesión de fíos incorrecta',
	'zxml_survoler' => 'sobrevoar para ver os correctos',
	'zxml_valeur_attribut' => 'valor do atributo',
	'zxml_vide_balise' => 'baliza baleira',
	'zxml_vu' => 'vista previa',
];
